The half maximal inhibitory concentration (IC50) is a measure of the effectiveness of a compound in inhibiting biological or biochemical function. This quantitative measure indicates how much of a particular drug or other substance (inhibitor) is needed to inhibit a given biological process (or component of a process) by half.
hillEquation(conc, occ, guess = c(1, 100), control = minpack.lm::nls.lm.control())a vector of drug concentrations in plasma (example units are ng/mL).
a vector of PET occupancy values that correspond to the measured drug concentrations in plasma.
a length-two vector of starting values for the nonlinear optimization.
is a list of parameters used by nls.lm.control
that are set by default, but may be customized by the user.
Half maximal inhibitory concentration
Estimated maximal occupancy
Approximate standard error for IC50
Approximate standard erorr for rmax
Hessian matrix from the Levenburg-Marquardt procedure
Return value from the Levenburg-Marquardt procedure
Deviance from the Levenburg-Marquardt procedure
Text message from the Levenburg-Marquardt procedure
See reference(s).
In this version of the function the maximal occupancy (rmax) is estimated automatically. This should be optional.
http://en.wikipedia.org/wiki/Hill_equation_(biochemistry) http://en.wikipedia.org/wiki/IC50