hillEquation(conc, occ, guess = c(1, 100), control = nls.lm.control())nls.lm.control
that are set by default, but may be customized by the user.In this version of the function the maximal occupancy (rmax) is estimated automatically. This should be optional.
nls.lm